# `asahi`

![Python package](https://github.com/kalaspuff/asahi/workflows/Python%20package/badge.svg)
[![pypi](https://badge.fury.io/py/asahi.svg)](https://pypi.python.org/pypi/asahi/)
[![Made with Python](https://img.shields.io/pypi/pyversions/asahi)](https://www.python.org/)
[![Type hinted - mypy validated](https://img.shields.io/badge/typehinted-yes-teal)](https://github.com/kalaspuff/asahi)
[![MIT License](https://img.shields.io/github/license/kalaspuff/asahi.svg)](https://github.com/kalaspuff/asahi/blob/master/LICENSE)
[![Code coverage](https://codecov.io/gh/kalaspuff/asahi/branch/master/graph/badge.svg)](https://codecov.io/gh/kalaspuff/asahi/tree/master/asahi)

*A small package to provide utility functions to libraries that has optional installs (so called "extras").*


## Installation with `pip`
Like you would install any other Python package, use `pip`, `poetry`, `pipenv` or your weapon of choice.
```
$ pip install asahi
```


## Usage and examples

#### Use-case
```
import asahi

```
